import { Grid, Skeleton, Typography } from "@mui/material";
import { InternalLink, EllipsisText, EmptyValue } from "@ess-ics/ce-ui-common";
import { useFindNetBoxHostByFqdnQuery } from "../../store/deployApi";

function shortenFqdn(fqdn) {
  return fqdn.split(".")[0];
}

function createHostLink(fqdn, hostInfo) {
  // if the fqdn field is empty for some reason
  if (fqdn === null || fqdn.trim() === "") {
    return <EmptyValue />;
  }

  // create host link only if the host exists in CSEntry
  if (hostInfo) {
    return (
      <InternalLink
        to={`/hosts/${hostInfo.hostId}`}
        label={`Record host details, ${fqdn}}`}
        width="100%"
      >
        <EllipsisText>{shortenFqdn(fqdn)}</EllipsisText>
      </InternalLink>
    );
  }

  return <Typography>{fqdn}</Typography>;
}

export const RecordHostLink = ({ fqdn }) => {
  const { data: hostInfo, isLoading } = useFindNetBoxHostByFqdnQuery({ fqdn });

  return (
    <Grid
      container
      direction="column"
      justifyContent="center"
      alignItems="center"
    >
      {isLoading || !hostInfo ? (
        <Skeleton width="100%" />
      ) : (
        createHostLink(fqdn, hostInfo)
      )}
    </Grid>
  );
};
